pub struct XuguConnection { /* private fields */ }Trait Implementations
Sourceimpl<'c> Acquire<'c> for &'c mut XuguConnection
impl<'c> Acquire<'c> for &'c mut XuguConnection
Sourceimpl Connection for XuguConnection
impl Connection for XuguConnection
type Database = Xugu
type Options = XuguConnectOptions
Sourcefn close(self) -> BoxFuture<'static, Result<(), Error>>
fn close(self) -> BoxFuture<'static, Result<(), Error>>
Explicitly close this database connection. Read more
Sourcefn ping(&mut self) -> BoxFuture<'_, Result<(), Error>>
fn ping(&mut self) -> BoxFuture<'_, Result<(), Error>>
Checks if a connection to the database is still valid.
Sourcefn begin(
&mut self,
) -> BoxFuture<'_, Result<Transaction<'_, Self::Database>, Error>>where
Self: Sized,
fn begin(
&mut self,
) -> BoxFuture<'_, Result<Transaction<'_, Self::Database>, Error>>where
Self: Sized,
Begin a new transaction or establish a savepoint within the active transaction. Read more
Sourcefn begin_with(
&mut self,
statement: impl Into<Cow<'static, str>>,
) -> BoxFuture<'_, Result<Transaction<'_, Self::Database>, Error>>where
Self: Sized,
fn begin_with(
&mut self,
statement: impl Into<Cow<'static, str>>,
) -> BoxFuture<'_, Result<Transaction<'_, Self::Database>, Error>>where
Self: Sized,
Begin a new transaction with a custom statement. Read more
Sourcefn cached_statements_size(&self) -> usize
fn cached_statements_size(&self) -> usize
The number of statements currently cached in the connection.
Sourcefn clear_cached_statements(&mut self) -> BoxFuture<'_, Result<(), Error>>
fn clear_cached_statements(&mut self) -> BoxFuture<'_, Result<(), Error>>
Removes all statements from the cache, closing them on the server if
needed.
Sourcefn shrink_buffers(&mut self)
fn shrink_buffers(&mut self)
Restore any buffers in the connection to their default capacity, if possible. Read more
Sourcefn is_in_transaction(&self) -> bool
fn is_in_transaction(&self) -> bool
Returns
true if the connection is currently in a transaction. Read moreSourcefn transaction<'a, F, R, E>(
&'a mut self,
callback: F,
) -> Pin<Box<dyn Future<Output = Result<R, E>> + Send + 'a>>
fn transaction<'a, F, R, E>( &'a mut self, callback: F, ) -> Pin<Box<dyn Future<Output = Result<R, E>> + Send + 'a>>
Execute the function inside a transaction. Read more
Sourceimpl Debug for XuguConnection
impl Debug for XuguConnection
Sourceimpl<'c> Executor<'c> for &'c mut XuguConnection
impl<'c> Executor<'c> for &'c mut XuguConnection
Sourcefn fetch_many<'e, 'q, E>(
self,
query: E,
) -> BoxStream<'e, Result<Either<XuguQueryResult, XuguRow>, Error>>
fn fetch_many<'e, 'q, E>( self, query: E, ) -> BoxStream<'e, Result<Either<XuguQueryResult, XuguRow>, Error>>
执行多个查询,并将生成的结果作为每个查询的流返回。
Sourcefn fetch_optional<'e, 'q, E>(
self,
query: E,
) -> BoxFuture<'e, Result<Option<XuguRow>, Error>>
fn fetch_optional<'e, 'q, E>( self, query: E, ) -> BoxFuture<'e, Result<Option<XuguRow>, Error>>
执行查询并最多返回一行。
Sourcefn prepare_with<'e, 'q: 'e>(
self,
sql: &'q str,
_parameters: &'e [XuguTypeInfo],
) -> BoxFuture<'e, Result<XuguStatement<'q>, Error>>where
'c: 'e,
fn prepare_with<'e, 'q: 'e>(
self,
sql: &'q str,
_parameters: &'e [XuguTypeInfo],
) -> BoxFuture<'e, Result<XuguStatement<'q>, Error>>where
'c: 'e,
准备 SQL 查询,其中包含参数类型信息,以检查有关其参数和结果的类型信息。
只有某些数据库驱动程序(PostgreSQL、MSSQL)可以利用此额外信息来影响参数类型推断。
type Database = Xugu
Sourcefn execute<'e, 'q, E>(
self,
query: E,
) -> Pin<Box<dyn Future<Output = Result<<Self::Database as Database>::QueryResult, Error>> + Send + 'e>>
fn execute<'e, 'q, E>( self, query: E, ) -> Pin<Box<dyn Future<Output = Result<<Self::Database as Database>::QueryResult, Error>> + Send + 'e>>
Execute the query and return the total number of rows affected.
Sourcefn execute_many<'e, 'q, E>(
self,
query: E,
) -> Pin<Box<dyn Stream<Item = Result<<Self::Database as Database>::QueryResult, Error>> + Send + 'e>>
fn execute_many<'e, 'q, E>( self, query: E, ) -> Pin<Box<dyn Stream<Item = Result<<Self::Database as Database>::QueryResult, Error>> + Send + 'e>>
Execute multiple queries and return the rows affected from each query, in a stream.
Sourcefn fetch<'e, 'q, E>(
self,
query: E,
) -> Pin<Box<dyn Stream<Item = Result<<Self::Database as Database>::Row, Error>> + Send + 'e>>
fn fetch<'e, 'q, E>( self, query: E, ) -> Pin<Box<dyn Stream<Item = Result<<Self::Database as Database>::Row, Error>> + Send + 'e>>
Execute the query and return the generated results as a stream.
Sourcefn fetch_all<'e, 'q, E>(
self,
query: E,
) -> Pin<Box<dyn Future<Output = Result<Vec<<Self::Database as Database>::Row>, Error>> + Send + 'e>>
fn fetch_all<'e, 'q, E>( self, query: E, ) -> Pin<Box<dyn Future<Output = Result<Vec<<Self::Database as Database>::Row>, Error>> + Send + 'e>>
Execute the query and return all the generated results, collected into a
Vec.Auto Trait Implementations
impl Freeze for XuguConnection
impl !RefUnwindSafe for XuguConnection
impl Send for XuguConnection
impl Sync for XuguConnection
impl Unpin for XuguConnection
impl UnsafeUnpin for XuguConnection
impl !UnwindSafe for XuguConnection